@@ -24,7 +24,8 @@
 */
 var NAVTREE =
 [
-  [ "Doxygen", "index.html", [
+  [ "Manual", "index.html", [
+    [ "Doxygen", "index.html", null ],
     [ "Installation", "install.html", [
       [ "Compiling from source on UNIX", "install.html#install_src_unix", null ],
       [ "Installing the binaries on UNIX", "install.html#install_bin_unix", null ],
@@ -32,9 +33,9 @@ var NAVTREE =
       [ "Installing the binaries on Windows", "install.html#install_bin_windows", null ]
     ] ],
     [ "Getting started", "starting.html", [
-      [ "Step 0: Check if doxygen supports your programming/hardware description language", "starting.html#step0", null ],
+      [ "Step 0: Check if Doxygen supports your programming/hardware description language", "starting.html#step0", null ],
       [ "Step 1: Creating a configuration file", "starting.html#step1", null ],
-      [ "Step 2: Running doxygen", "starting.html#step2", [
+      [ "Step 2: Running Doxygen", "starting.html#step2", [
         [ "HTML output", "starting.html#html_out", null ],
         [ "LaTeX output", "starting.html#latex_out", null ],
         [ "RTF output", "starting.html#rtf_out", null ],
@@ -57,6 +58,13 @@ var NAVTREE =
       ] ],
       [ "Anatomy of a comment block", "docblocks.html#docstructure", null ]
     ] ],
+    [ "Additional Documentation", "additional.html", [
+      [ "Custom Pages", "additional.html#custom_pages", null ],
+      [ "Scaling Up", "additional.html#scaling", [
+        [ "Automatically Adding Files", "additional.html#automatically_adding_files", null ],
+        [ "Side Panel Treeview", "additional.html#treeview", null ]
+      ] ]
+    ] ],
     [ "Markdown support", "markdown.html", [
       [ "Standard Markdown", "markdown.html#markdown_std", [
         [ "Paragraphs", "markdown.html#md_para", null ],
@@ -90,13 +98,14 @@ var NAVTREE =
         [ "Code Spans Limits", "markdown.html#mddox_code_spans", null ],
         [ "Lists Extensions", "markdown.html#mddox_lists", null ],
         [ "Use of asterisks", "markdown.html#mddox_stars", null ],
-        [ "Limits on markup scope", "markdown.html#mddox_limits", null ]
+        [ "Limits on markup scope", "markdown.html#mddox_limits", null ],
+        [ "Support for GitHub Alerts", "markdown.html#mddox_github_alerts", null ]
       ] ],
       [ "Debugging problems", "markdown.html#markdown_debug", null ]
     ] ],
     [ "Lists", "lists.html", null ],
     [ "Grouping", "grouping.html", [
-      [ "Modules", "grouping.html#modules", null ],
+      [ "Topics", "grouping.html#topics", null ],
       [ "Member Groups", "grouping.html#memgroup", null ],
       [ "Subpaging", "grouping.html#subpaging", null ]
     ] ],
@@ -135,22 +144,22 @@ var NAVTREE =
       [ "Help, some/all of the members of my class / file / namespace are not documented?", "faq.html#fac_al", null ],
       [ "When I set EXTRACT_ALL to NO none of my functions are shown in the documentation.", "faq.html#faq_extract_all", null ],
       [ "My file with a custom extension is not parsed (properly) (anymore).", "faq.html#faq_ext_mapping", null ],
-      [ "How can I make doxygen ignore some code fragment?", "faq.html#faq_code", null ],
+      [ "How can I make Doxygen ignore some code fragment?", "faq.html#faq_code", null ],
       [ "How can I change what is after the #include in the class documentation?", "faq.html#faq_code_inc", null ],
       [ "How can I use tag files in combination with compressed HTML?", "faq.html#faq_chm", null ],
       [ "I don't like the quick index that is put above each HTML page, what do I do?", "faq.html#faq_html", null ],
       [ "The overall HTML output looks different, while I only wanted to use my own html header file", "faq.html#faq_html_header", null ],
-      [ "Why does doxygen use Qt?", "faq.html#faq_use_qt", null ],
+      [ "Why does Doxygen use Qt?", "faq.html#faq_use_qt", null ],
       [ "How can I exclude all test directories from my directory tree?", "faq.html#faq_excl_dir", null ],
-      [ "Doxygen automatically generates a link to the class MyClass somewhere in the running text.  How do I prevent that at a certain place?", "faq.html#faq_class", null ],
-      [ "My favorite programming language is X. Can I still use doxygen?", "faq.html#faq_pgm_X", null ],
-      [ "Help! I get the cryptic message \"input buffer overflow, can't enlarge buffer because scanner uses REJECT\"", "faq.html#faq_lex", null ],
+      [ "Doxygen automatically generates a link to the class MyClass somewhere in the running text....", "faq.html#faq_class", null ],
+      [ "My favorite programming language is X. Can I still use Doxygen?", "faq.html#faq_pgm_X", null ],
+      [ "Help! I get the cryptic message \"input buffer overflow, can't enlarge buffer because scanner uses REJ...", "faq.html#faq_lex", null ],
       [ "When running make in the latex directory I get \"TeX capacity exceeded\". Now what?", "faq.html#faq_latex", null ],
       [ "Why are dependencies via STL classes not shown in the dot graphs?", "faq.html#faq_stl", null ],
       [ "I have problems getting the search engine to work with PHP5 and/or windows", "faq.html#faq_search", null ],
-      [ "Can I configure doxygen from the command line?", "faq.html#faq_cmdline", null ],
-      [ "How did doxygen get its name?", "faq.html#faq_name", null ],
-      [ "What was the reason to develop doxygen?", "faq.html#faq_why", null ],
+      [ "Can I configure Doxygen from the command line?", "faq.html#faq_cmdline", null ],
+      [ "How did Doxygen get its name?", "faq.html#faq_name", null ],
+      [ "What was the reason to develop Doxygen?", "faq.html#faq_why", null ],
       [ "How to prevent interleaved output", "faq.html#faq_bin", null ]
     ] ],
     [ "Troubleshooting", "trouble.html", [
@@ -210,6 +219,22 @@ var NAVTREE =
       [ "\\hiderefby", "commands.html#cmdhiderefby", null ],
       [ "\\showrefs", "commands.html#cmdshowrefs", null ],
       [ "\\hiderefs", "commands.html#cmdhiderefs", null ],
+      [ "\\showinlinesource", "commands.html#cmdshowinlinesource", null ],
+      [ "\\hideinlinesource", "commands.html#cmdhideinlinesource", null ],
+      [ "\\includegraph", "commands.html#cmdincludegraph", null ],
+      [ "\\hideincludegraph", "commands.html#cmdhideincludegraph", null ],
+      [ "\\includedbygraph", "commands.html#cmdincludedbygraph", null ],
+      [ "\\hideincludedbygraph", "commands.html#cmdhideincludedbygraph", null ],
+      [ "\\directorygraph", "commands.html#cmddirectorygraph", null ],
+      [ "\\hidedirectorygraph", "commands.html#cmdhidedirectorygraph", null ],
+      [ "\\collaborationgraph", "commands.html#cmdcollaborationgraph", null ],
+      [ "\\hidecollaborationgraph", "commands.html#cmdhidecollaborationgraph", null ],
+      [ "\\inheritancegraph['{option}']", "commands.html#cmdinheritancegraph", null ],
+      [ "\\hideinheritancegraph", "commands.html#cmdhideinheritancegraph", null ],
+      [ "\\groupgraph", "commands.html#cmdgroupgraph", null ],
+      [ "\\hidegroupgraph", "commands.html#cmdhidegroupgraph", null ],
+      [ "\\showenumvalues", "commands.html#cmdshowenumvalues", null ],
+      [ "\\hideenumvalues", "commands.html#cmdhideenumvalues", null ],
       [ "\\qualifier <label> | \"(text)\"", "commands.html#cmdqualifier", null ],
       [ "\\category <name> [<header-file>] [<header-name>]", "commands.html#cmdcategory", null ],
       [ "\\class <name> [<header-file>] [<header-name>]", "commands.html#cmdclass", null ],
@@ -234,6 +259,7 @@ var NAVTREE =
       [ "\\internal", "commands.html#cmdinternal", null ],
       [ "\\mainpage [(title)]", "commands.html#cmdmainpage", null ],
       [ "\\memberof <name>", "commands.html#cmdmemberof", null ],
+      [ "\\module <name>", "commands.html#cmdmodule", null ],
       [ "\\name [(header)]", "commands.html#cmdname", null ],
       [ "\\namespace <name>", "commands.html#cmdnamespace", null ],
       [ "\\nosubgrouping", "commands.html#cmdnosubgrouping", null ],
@@ -281,10 +307,11 @@ var NAVTREE =
       [ "\\exception <exception-object> { exception description }", "commands.html#cmdexception", null ],
       [ "\\if (section-label)", "commands.html#cmdif", null ],
       [ "\\ifnot (section-label)", "commands.html#cmdifnot", null ],
+      [ "\\important { important text }", "commands.html#cmdimportant", null ],
       [ "\\invariant { description of invariant }", "commands.html#cmdinvariant", null ],
       [ "\\note { text }", "commands.html#cmdnote", null ],
       [ "\\par [(paragraph title)] { paragraph }", "commands.html#cmdpar", null ],
-      [ "\\param '['dir']' <parameter-name> { parameter description }", "commands.html#cmdparam", null ],
+      [ "\\param[<dir>] <parameter-name> { parameter description }", "commands.html#cmdparam", null ],
       [ "\\parblock", "commands.html#cmdparblock", null ],
       [ "\\endparblock", "commands.html#cmdendparblock", null ],
       [ "\\tparam <template-parameter-name> { description }", "commands.html#cmdtparam", null ],
@@ -322,19 +349,21 @@ var NAVTREE =
       [ "\\subsection <subsection-name> (subsection title)", "commands.html#cmdsubsection", null ],
       [ "\\subsubsection <subsubsection-name> (subsubsection title)", "commands.html#cmdsubsubsection", null ],
       [ "\\paragraph <paragraph-name> (paragraph title)", "commands.html#cmdparagraph", null ],
+      [ "\\subparagraph <subparagraph-name> (subparagraph title)", "commands.html#cmdsubparagraph", null ],
+      [ "\\subsubparagraph <subsubparagraph-name> (subsubparagraph title)", "commands.html#cmdsubsubparagraph", null ],
       [ "\\dontinclude['{lineno}'] <file-name>", "commands.html#cmddontinclude", null ],
       [ "\\include['{'option'}'] <file-name>", "commands.html#cmdinclude", null ],
       [ "\\includelineno <file-name>", "commands.html#cmdincludelineno", null ],
-      [ "\\includedoc <file-name>", "commands.html#cmdincludedoc", null ],
+      [ "\\includedoc['{'option'}'] <file-name>", "commands.html#cmdincludedoc", null ],
       [ "\\line ( pattern )", "commands.html#cmdline", null ],
       [ "\\skip ( pattern )", "commands.html#cmdskip", null ],
       [ "\\skipline ( pattern )", "commands.html#cmdskipline", null ],
       [ "\\snippet['{'option'}'] <file-name> ( block_id )", "commands.html#cmdsnippet", null ],
       [ "\\snippetlineno <file-name> ( block_id )", "commands.html#cmdsnippetlineno", null ],
-      [ "\\snippetdoc <file-name> ( block_id )", "commands.html#cmdsnippetdoc", null ],
+      [ "\\snippetdoc['{'option'}'] <file-name> ( block_id )", "commands.html#cmdsnippetdoc", null ],
       [ "\\until ( pattern )", "commands.html#cmduntil", null ],
       [ "\\verbinclude <file-name>", "commands.html#cmdverbinclude", null ],
-      [ "\\htmlinclude [\"[block]\"] <file-name>", "commands.html#cmdhtmlinclude", null ],
+      [ "\\htmlinclude['[block]'] <file-name>", "commands.html#cmdhtmlinclude", null ],
       [ "\\latexinclude <file-name>", "commands.html#cmdlatexinclude", null ],
       [ "\\rtfinclude <file-name>", "commands.html#cmdrtfinclude", null ],
       [ "\\maninclude <file-name>", "commands.html#cmdmaninclude", null ],
@@ -364,6 +393,7 @@ var NAVTREE =
       [ "\\enddot", "commands.html#cmdenddot", null ],
       [ "\\endmsc", "commands.html#cmdendmsc", null ],
       [ "\\enduml", "commands.html#cmdenduml", null ],
+      [ "\\plantumlfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdplantumlfile", null ],
       [ "\\endhtmlonly", "commands.html#cmdendhtmlonly", null ],
       [ "\\endlatexonly", "commands.html#cmdendlatexonly", null ],
       [ "\\endmanonly", "commands.html#cmdendmanonly", null ],
@@ -377,7 +407,7 @@ var NAVTREE =
       [ "\\f]", "commands.html#cmdfbrclose", null ],
       [ "\\f{environment}{", "commands.html#cmdfcurlyopen", null ],
       [ "\\f}", "commands.html#cmdfcurlyclose", null ],
-      [ "\\htmlonly [\"[block]\"]", "commands.html#cmdhtmlonly", null ],
+      [ "\\htmlonly['[block]']", "commands.html#cmdhtmlonly", null ],
       [ "\\image['{'option[,option]'}'] <format> <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdimage", null ],
       [ "\\latexonly", "commands.html#cmdlatexonly", null ],
       [ "\\manonly", "commands.html#cmdmanonly", null ],
@@ -398,11 +428,13 @@ var NAVTREE =
       [ "\\%", "commands.html#cmdperc", null ],
       [ "\\\"", "commands.html#cmdquot", null ],
       [ "\\.", "commands.html#cmdchardot", null ],
+      [ "\\?", "commands.html#cmdquest", null ],
+      [ "\\!", "commands.html#cmdexclam", null ],
       [ "\\=", "commands.html#cmdeq", null ],
       [ "\\::", "commands.html#cmddcolon", null ],
       [ "\\|", "commands.html#cmdpipe", null ],
-      [ "\\–", "commands.html#cmdndash", null ],
-      [ "\\—", "commands.html#cmdmdash", null ]
+      [ "\\--", "commands.html#cmdndash", null ],
+      [ "\\---", "commands.html#cmdmdash", null ]
     ] ],
     [ "HTML Commands", "htmlcmds.html", [
       [ "HTML tag commands", "htmlcmds.html#htmltagcmds", null ],
@@ -425,7 +457,22 @@ var NAVTREE =
     ] ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
+      [ "1.13 Series", "changelog.html#log_1_13", [
+        [ "Release 1.13.2", "changelog.html#log_1_13_2", null ],
+        [ "Release 1.13.1", "changelog.html#log_1_13_1", null ],
+        [ "Release 1.13.0", "changelog.html#log_1_13_0", null ]
+      ] ],
+      [ "1.12 Series", "changelog.html#log_1_12", [
+        [ "Release 1.12.0", "changelog.html#log_1_12_0", null ]
+      ] ],
+      [ "1.11 Series", "changelog.html#log_1_11", [
+        [ "Release 1.11.0", "changelog.html#log_1_11_0", null ]
+      ] ],
+      [ "1.10 Series", "changelog.html#log_1_10", [
+        [ "Release 1.10.0", "changelog.html#log_1_10_0", null ]
+      ] ],
       [ "1.9 Series", "changelog.html#log_1_9", [
+        [ "Release 1.9.8", "changelog.html#log_1_9_8", null ],
         [ "Release 1.9.7", "changelog.html#log_1_9_7", null ],
         [ "Release 1.9.6", "changelog.html#log_1_9_6", null ],
         [ "Release 1.9.5", "changelog.html#log_1_9_5", null ],
@@ -475,9 +522,9 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"arch.html",
-"commands.html#cmdwarning"
+"additional.html",
+"commands.html#cmdsecreflist"
 ];
 
-var SYNCONMSG = 'click to disable panel synchronisation';
-var SYNCOFFMSG = 'click to enable panel synchronisation';
\ No newline at end of file
+var SYNCONMSG = 'click to disable panel synchronization';
+var SYNCOFFMSG = 'click to enable panel synchronization';
\ No newline at end of file
